@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.0102';
+our $VERSION = '0.02';
 
 use Moo;
 use strictures 2;
@@ -233,7 +233,7 @@ sub populate {
         for my $channel ( sort { $a <=> $b } keys %{ $self->notes } ) {
             # Create a function that adds notes to the score
             my $func = sub {
-                my $patch = $self->randpatch ? _random_patch() : 0;
+                my $patch = $self->randpatch ? $self->_random_patch() : 0;
 
                 _set_chan_patch( $self->score, $channel, $patch );
 
@@ -296,7 +296,7 @@ sub populate {
 
             # Create a function that adds our bucket of notes to the score
             my $func = sub {
-                my $patch = $self->randpatch ? _random_patch() : 0;
+                my $patch = $self->randpatch ? $self->_random_patch() : 0;
 
                 _set_chan_patch( $self->score, $channel, $patch);
 
@@ -391,16 +391,17 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.0102
+version 0.02
 
 =head1 SYNOPSIS
 
   use MIDI::Ngram;
   my $mng = MIDI::Ngram->new(
-    file    => 'eg/twinkle_twinkle.mid',
-    size    => 3,
-    patches => [qw( 68 69 70 71 72 73 )],
-    verbose => 1,
+    file      => 'eg/twinkle_twinkle.mid',
+    size      => 3,
+    patches   => [qw( 68 69 70 71 72 73 )],
+    randpatch => 1,
+    verbose   => 1,
   );
   $mng->process;
   $mng->populate;
